Struct audio_time::Bytes

source ·
#[repr(transparent)]
pub struct Bytes<const SYS: System>(_);
An audio time span, measured in the number of bytes required for its representation.

The usize contained in this struct is invariantly held to be divisible (without remainder) by the size of a single sample (SYS.sample_size()).

Implementations

source

impl<const SYS: System> Bytes<SYS>

source

pub const fn new(n: usize) -> Option<Self>

Create a Bytes if the given value is divisible by SYS.sample_size().

source

pub const fn get(&self) -> usize

source

impl<const SYS: System> Bytes<SYS>

source

pub const fn into_duration(self) -> Duration

Equivalent to Duration::try_from(bytes).unwrap().

source

pub const fn from_duration(dur: Duration) -> Self

Equivalent to Bytes::try_from(duration).unwrap().

source

pub const fn into_samples(self) -> Samples<SYS>

Equivalent to Samples::from(bytes).

source

pub const fn from_samples(samples: Samples<SYS>) -> Self

Equivalent to Bytes::try_from(samples).unwrap().