Struct audio_time::Bytes
source · #[repr(transparent)]pub struct Bytes<const SYS: System>(_);Expand description
An audio time span, measured in the number of bytes required for its representation.
The usize contained in this struct is invariantly held to be divisible
(without remainder) by the size of a single sample
(SYS.sample_size()).
Implementations
sourceimpl<const SYS: System> Bytes<SYS>
impl<const SYS: System> Bytes<SYS>
sourcepub const fn into_duration(self) -> Duration
pub const fn into_duration(self) -> Duration
Equivalent to Duration::try_from(bytes).unwrap().
sourcepub const fn from_duration(dur: Duration) -> Self
pub const fn from_duration(dur: Duration) -> Self
Equivalent to Bytes::try_from(duration).unwrap().
sourcepub const fn into_samples(self) -> Samples<SYS>
pub const fn into_samples(self) -> Samples<SYS>
Equivalent to Samples::from(bytes).
sourcepub const fn from_samples(samples: Samples<SYS>) -> Self
pub const fn from_samples(samples: Samples<SYS>) -> Self
Equivalent to Bytes::try_from(samples).unwrap().